==> dcl-5.0.tar.gz: dcl-5.0/src/grph2/uspack/uscqnp.f <==
*-----------------------------------------------------------------------
*     USCQNP
*-----------------------------------------------------------------------
      SUBROUTINE USCQNP(NCP)

      CHARACTER CP*(*), CVAL*(*)

      PARAMETER (NPARA=9)

      CHARACTER CPARA(NPARA)*8,  CX(NPARA)*80, CMSG*80
      LOGICAL   LCHREQ, LFIRST
      SAVE

      DATA      CPARA( 1)/'CXSIDE  '/, CX(1) /'BT'/
      DATA      CPARA( 2)/'CYSIDE  '/, CX(2) /'LR'/
      DATA      CPARA( 3)/'CXSPOS  '/, CX(3) /'R '/
      DATA      CPARA( 4)/'CYSPOS  '/, CX(4) /'T '/
      DATA      CPARA( 5)/'CBLKT   '/, CX(5) /'()'/

      DATA      CPARA( 6)/'CXTTL   '/, CX(6)/ ' '/
      DATA      CPARA( 7)/'CYTTL   '/, CX(7)/ ' '/
      DATA      CPARA( 8)/'CXUNIT  '/, CX(8)/ ' '/
      DATA      CPARA( 9)/'CYUNIT  '/, CX(9)/ ' '/

      DATA      LFIRST /.TRUE./

      NCP = NPARA

      RETURN
*-----------------------------------------------------------------------
      ENTRY USCQID(CP, IDX)

      DO 10 N=1,NPARA
        IF (LCHREQ(CP,CPARA(N))) THEN
          IDX = N
          RETURN
        END IF
   10 CONTINUE

      CMSG='PARAMETER "'//CP(1:LENC(CP))//'" IS NOT DEFINED.'
      CALL MSGDMP('E','USCQID',CMSG)

      RETURN
*-----------------------------------------------------------------------
      ENTRY USCQCP(IDX,CP)

      IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
        CP=CPARA(IDX)
      ELSE
        CALL MSGDMP('E','USCQCP','IDX IS OUT OF RANGE.')
      END IF

      RETURN
*-----------------------------------------------------------------------
      ENTRY USCQVL(IDX,CVAL)

      IF(LFIRST) THEN
        CALL RTCGET('US:', CPARA, CX, NPARA)
        LFIRST = .FALSE.
      ENDIF

      IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
        CVAL=CX(IDX)
      ELSE
        CALL MSGDMP('E','USCQVL','IDX IS OUT OF RANGE.')
      END IF

      RETURN
*-----------------------------------------------------------------------
      ENTRY USCSVL(IDX,CVAL)

      IF(LFIRST) THEN
        CALL RTCGET('US:', CPARA, CX, NPARA)
        LFIRST = .FALSE.
      ENDIF

      IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
        CX(IDX)=CVAL
      ELSE
        CALL MSGDMP('E','USCSVL','IDX IS OUT OF RANGE.')
      END IF

      RETURN
      END

==> dcl_5.0.1-4.tar.gz: dcl-5.0.1/src/grph2/uspack/uscqnp.f <==
*-----------------------------------------------------------------------
*     USCQNP                                          DCL 5.0  95/09/04
*-----------------------------------------------------------------------
      SUBROUTINE USCQNP(NCP)

      CHARACTER CP*(*), CVAL*(*)

      PARAMETER (NPARA=11)

      CHARACTER CPARA(NPARA)*8,  CX(NPARA)*80, CMSG*80
      LOGICAL   LCHREQ, LFIRST
      SAVE

      DATA      CPARA( 1)/'CXSIDE  '/, CX( 1) /'BT'/
      DATA      CPARA( 2)/'CYSIDE  '/, CX( 2) /'LR'/
      DATA      CPARA( 3)/'CXSPOS  '/, CX( 3) /'R '/
      DATA      CPARA( 4)/'CYSPOS  '/, CX( 4) /'T '/
      DATA      CPARA( 5)/'CBLKT   '/, CX( 5) /'()'/

      DATA      CPARA( 6)/'CXTTL   '/, CX( 6)/ ' '/
      DATA      CPARA( 7)/'CYTTL   '/, CX( 7)/ ' '/
      DATA      CPARA( 8)/'CXUNIT  '/, CX( 8)/ ' '/
      DATA      CPARA( 9)/'CYUNIT  '/, CX( 9)/ ' '/
      DATA      CPARA(10)/'CXFMT   '/, CX(10)/ ' '/
      DATA      CPARA(11)/'CYFMT   '/, CX(11)/ ' '/

      DATA      LFIRST /.TRUE./

      NCP = NPARA

      RETURN
*-----------------------------------------------------------------------
      ENTRY USCQID(CP, IDX)

      DO 10 N=1,NPARA
        IF (LCHREQ(CP,CPARA(N))) THEN
          IDX = N
          RETURN
        END IF
   10 CONTINUE

      CMSG='PARAMETER "'//CP(1:LENC(CP))//'" IS NOT DEFINED.'
      CALL MSGDMP('E','USCQID',CMSG)

      RETURN
*-----------------------------------------------------------------------
      ENTRY USCQCP(IDX,CP)

      IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
        CP=CPARA(IDX)
      ELSE
        CALL MSGDMP('E','USCQCP','IDX IS OUT OF RANGE.')
      END IF

      RETURN
*-----------------------------------------------------------------------
      ENTRY USCQVL(IDX,CVAL)

      IF(LFIRST) THEN
        CALL RTCGET('US:', CPARA, CX, NPARA)
        LFIRST = .FALSE.
      ENDIF

      IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
        CVAL=CX(IDX)
      ELSE
        CALL MSGDMP('E','USCQVL','IDX IS OUT OF RANGE.')
      END IF

      RETURN
*-----------------------------------------------------------------------
      ENTRY USCSVL(IDX,CVAL)

      IF(LFIRST) THEN
        CALL RTCGET('US:', CPARA, CX, NPARA)
        LFIRST = .FALSE.
      ENDIF

      IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
        CX(IDX)=CVAL
      ELSE
        CALL MSGDMP('E','USCSVL','IDX IS OUT OF RANGE.')
      END IF

      RETURN
      END
